==> pwdutils-2.6.95.tar.gz: pwdutils-2.6.95/lib/msg_table.h <==
/* Copyright (C) 2004 Thorsten Kukuk
   Author: Thorsten Kukuk <kukuk@suse.de>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2 as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

static char *msg_table[] = {
  /*  0 */ "NULL",
  /*  1 */ "path specification denied - by=%u",
  "permission denied - name=%s, id=%u, by=%u",
  "password aging information displayed - user=%s, uid=%u, by=%u",
  "group is unknown - group=%s, by=%u",
  "user changing the password for group - group=%s, by=%u",
  "password change aborted - for=%s, by=%u",
  "password modification exceeded max tries, aborted - group=%s, by=%u",
  "failed to change group password - group=%s, by=%u",
  "group password removed - group=%s, gid=%u, by=%u",
  /* 10 */ "group password changed - group=%s, gid=%u, by=%u",
  "can't get unique gid in range %u - %u",
  "GID %u is not unique - by=%u",
  "invalid name - group=%s, by=%u",
  "cannot lock group file: already locked",
  "group already exists - group=%s, by=%u",
  "failed to add new group - group=%s, gid=%u, by=%u",
  "new group added - group=%s, gid=%u, by=%u",
  "GID `%u' is primary group of `%s' - by=%u",
  "cannot remove user's primary group - group=%s, by=%u",
  /* 20 */ "failed to delete group - group=%s, gid=%u, by=%u",
  "group deleted - group=%s, gid=%u, by=%u",
  "cannot lock password file: already locked",
  "failed to modify group - group=%s, gid=%u, by=%u",
  "account removed from group - account=%s, group=%s, gid=%u, by=%u",
  "account added to group - account=%s, group=%s, gid=%u, by=%u",
  "group name changed  - group=%s, old group=%s, gid=%u, by=%u",
  "group gid changed - group=%s, gid=%u, old gid=%u, by=%u",
  "password status display for all users denied - by=%u",
  "password status displayed for all users - by=%u",
  /* 30 */ "user is unknown - user=%s, by=%u",
  /* 31 */ "password change denied - user=%s, uid=%u, by=%u",
  /* 32 */ "password status displayed - user=%s, uid=%u, by=%u",
  /* 33 */ "password change failed, pam error %d - user=%s, uid=%u, by=%u",
  /* 34 */ "password changed - user=%s, uid=%u, by=%u",
  /* 35 */ "can't get unique uid in range %u - %u",
  /* 36 */ "cannot determine user name - uid=%u",
  /* 37 */ "defaults changed - gid=%u, home=%s, shell=%s, inactive=%li, expire=%s, by=%u",
  /* 38 */ "updating default config file `%s' faild - by=%u",
  /* 39 */ "UID %u is not unique - by=%u",
  /* 40 */ "invalid name - account=%s, by=%u",
  "account already exists - account=%s, by=%u",
  "new account added - account=%s, uid=%u, gid=%u, home=%s, shell=%s, by=%u",
  "home directory created - account=%s, uid=%u, home=%s, by=%u",
  "running %s command - script=%s, account=%s, uid=%u, gid=%u, home=%s, by=%u",
  "error removing account from group - account=%s, uid=%u, group=%s, gid=%u, by=%u",
  "`%s' is not owned by user, not removed - account=%s, uid=%u, by %u",
  "home directory deleted - account=%s, uid=%u, home=%s, by=%u",
  "failed to delete account - account=%s, uid=%u, by=%u",
  "account deleted - account=%s, uid=%u, by=%u",
  /* 50 */ "error renaming account in group - account=%s, uid=%u, group=%s, gid=%u, by=%u",
  /* 51 */ "account name renamed in group - new=%s, old=%s, uid=%u, group=%s, gid=%u, by=%u",
  /* 52 */ "failed to modify account - account=%s, uid=%u, by=%u",
  /* 53 */ "account is currently in use - account=%s, uid=%u, by=%u",
  /* 54 */ "account name changed - new=%s, old=%s, uid=%u, by=%u",
  /* 55 */ "UID changed - account=%s, new id=%u, old id=%u, by=%u",
  /* 56 */ "account GECOS changed - account=%s, uid=%u, GECOS='%s', old GECOS='%s', by=%u",
  /* 57 */ "default group changed - account=%s, uid=%u, gid=%u, old gid=%u, by=%u",
  /* 58 */ "home directory changed - account=%s, uid=%u, home=%s, old home=%s, by=%u",
  /* 59 */ "shell changed - account=%s, uid=%u, shell=%s, old shell=%s, by=%u",
  /* 60 */ "inactive days changed - account=%s, uid=%u, inactive=%li, old=%li, by=%u",
  /* 61 */ "expiration date changed - account=%s, uid=%u, expire=%s, old date=%s, by=%u"};

==> pwdutils-2.6.98.tar.gz: pwdutils-2.6.98/lib/msg_table.h <==
/* Copyright (C) 2004, 2005 Thorsten Kukuk
   Author: Thorsten Kukuk <kukuk@suse.de>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2 as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

static char *msg_table[] = {
  /*  0 */ "NULL",
  /*  1 */ "path specification denied - by=%u",
  "permission denied - account=%s, id=%u, by=%u",
  "password aging information displayed - account=%s, uid=%u, by=%u",
  "group is unknown - group=%s, by=%u",
  "user changing the password for group - group=%s, by=%u",
  "password change aborted - for=%s, by=%u",
  "password modification exceeded max tries, aborted - group=%s, by=%u",
  "failed to change group password - group=%s, by=%u",
  "group password removed - group=%s, gid=%u, by=%u",
  /* 10 */ "group password changed - group=%s, gid=%u, by=%u",
  "can't get unique gid in range %u - %u",
  "GID %u is not unique - by=%u",
  "invalid name - group=%s, by=%u",
  "cannot lock group file: already locked",
  "group already exists - group=%s, by=%u",
  "failed to add new group - group=%s, gid=%u, by=%u",
  "new group added - group=%s, gid=%u, by=%u",
  "GID `%u' is primary group of `%s' - by=%u",
  "cannot remove user's primary group - group=%s, by=%u",
  /* 20 */ "failed to delete group - group=%s, gid=%u, by=%u",
  "group deleted - group=%s, gid=%u, by=%u",
  "cannot lock password file: already locked",
  "failed to modify group - group=%s, gid=%u, by=%u",
  "account removed from group - account=%s, group=%s, gid=%u, by=%u",
  "account added to group - account=%s, group=%s, gid=%u, by=%u",
  "group name changed  - group=%s, old group=%s, gid=%u, by=%u",
  "group gid changed - group=%s, gid=%u, old gid=%u, by=%u",
  "password status display for all users denied - by=%u",
  "password status displayed for all users - by=%u",
  /* 30 */ "account is unknown - account=%s, by=%u",
  /* 31 */ "password change denied - account=%s, uid=%u, by=%u",
  /* 32 */ "password status displayed - account=%s, uid=%u, by=%u",
  /* 33 */ "password change failed, pam error %d - account=%s, uid=%u, by=%u",
  /* 34 */ "password changed - account=%s, uid=%u, by=%u",
  /* 35 */ "can't get unique uid in range %u - %u",
  /* 36 */ "cannot determine account name - uid=%u",
  /* 37 */ "defaults changed - gid=%u, home=%s, shell=%s, inactive=%li, expire=%s, by=%u",
  /* 38 */ "updating default config file `%s' faild - by=%u",
  /* 39 */ "UID %u is not unique - by=%u",
  /* 40 */ "invalid name - account=%s, by=%u",
  "account already exists - account=%s, by=%u",
  "new account added - account=%s, uid=%u, gid=%u, home=%s, shell=%s, by=%u",
  "home directory created - account=%s, uid=%u, home=%s, by=%u",
  "running %s command - script=%s, account=%s, uid=%u, gid=%u, home=%s, by=%u",
  "error removing account from group - account=%s, uid=%u, group=%s, gid=%u, by=%u",
  "`%s' is not owned by user, not removed - account=%s, uid=%u, by %u",
  "home directory deleted - account=%s, uid=%u, home=%s, by=%u",
  "failed to delete account - account=%s, uid=%u, by=%u",
  "account deleted - account=%s, uid=%u, by=%u",
  /* 50 */ "error renaming account in group - account=%s, uid=%u, group=%s, gid=%u, by=%u",
  /* 51 */ "account name renamed in group - new=%s, old=%s, uid=%u, group=%s, gid=%u, by=%u",
  /* 52 */ "failed to modify account - account=%s, uid=%u, by=%u",
  /* 53 */ "account is currently in use - account=%s, uid=%u, by=%u",
  /* 54 */ "account name changed - new=%s, old=%s, uid=%u, by=%u",
  /* 55 */ "UID changed - account=%s, new id=%u, old id=%u, by=%u",
  /* 56 */ "account GECOS changed - account=%s, uid=%u, GECOS='%s', old GECOS='%s', by=%u",
  /* 57 */ "default group changed - account=%s, uid=%u, gid=%u, old gid=%u, by=%u",
  /* 58 */ "home directory changed - account=%s, uid=%u, home=%s, old home=%s, by=%u",
  /* 59 */ "shell changed - account=%s, uid=%u, shell=%s, old shell=%s, by=%u",
  /* 60 */ "inactive days changed - account=%s, uid=%u, inactive=%li, old=%li, by=%u",
  /* 61 */ "expiration date changed - account=%s, uid=%u, expire=%s, old date=%s, by=%u",
  /* 62 */ "failed to drop privileges, errno=%d - by=%u"};
